/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * A convenient place to store all global configuration for
 * a client tunneler.
 *
 * $Id: ClientSideConfig.hh,v 1.4 2012/12/27 13:26:45 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _GLOBAL_CLIENT_CONFIG_HH_
#define _GLOBAL_CLIENT_CONFIG_HH_

#include <string>
#include "Enums.hh"
#include "SideConfig.hh"

namespace HTTPTunnel {

class ProxySettings;
class Authenticator;
class ClientAuthenticator;

class ClientSideConfig : public SideConfig {
public:
	// Construction/destruction
	ClientSideConfig(Enums::Protocol prot, bool ssl, bool sockTun, IPAddr listenIP,
		IPAddr serverIP, std::string suser, std::string spasswd, std::string dhost,
		unsigned int dport, std::string tune);
	ClientSideConfig(Enums::Protocol prot, bool ssl, bool sockTun, IPAddr listenIP,
		IPAddr serverIP, std::string suser, std::string spasswd, std::string dhost,
		unsigned int dport, std::string tune, IPAddr proxyIP, std::string puser,
		std::string ppasswd);
	ClientSideConfig(Enums::Protocol prot, bool ssl, IPAddr listenIP, IPAddr serverIP,
		std::string suser, std::string spasswd, std::string tune);
	ClientSideConfig(Enums::Protocol prot, bool ssl, IPAddr listenIP, IPAddr serverIP,
		std::string suser, std::string spasswd, std::string tune, IPAddr proxyIP,
		std::string puser, std::string ppasswd);
	virtual ~ClientSideConfig();


	/*************/
	/* Accessors */
	/*************/

	// Client config?
	virtual bool isClient(void) const;

	// Are we going via a proxy?
	bool viaProxy(void) const;

	// What type of tunneler are we for?
	bool fixed(void) const;
	bool socks(void) const;

	// Get address for server end of tunnel
	IPAddr getServerIP(void) const;
	std::string getResolvedServerIP(void) const;

	// Get address for fixed tunnel destination
	IPAddr getFixedDestIP(void) const;

	// Get address for next hop in tunnel
	IPAddr getNextHopIP(void) const;

	// Proxy settings
	const ProxySettings* getProxySettings(void) const;

	// Tunnel tuning
	std::string getTunTune(void) const;


	/************/
	/* Mutators */
	/************/

	// Set client authorisation
	void setClientAuth(std::string user, std::string passwd);


	/*************/
	/* Utilities */
	/*************/

	// Serialize to a file
	virtual void serialize(std::ofstream& file);


protected:

	/***********/
	/* Methods */
	/***********/

	// Get domain for user
	std::string lookupUserDomain(std::string& user);


	/********/
	/* Data */
	/********/

	// IP address of server end
	IPAddr							m_serverIP;
	std::string						m_resolvedServerIP;

	// IP address for fixed tunnel destination
	IPAddr							m_fixedDestIP;

	// Proxy/serverauth settings
	ProxySettings*					m_proxySettings;

	// Tunnel tuning
	std::string						m_tune;

};


}	// namespace

#endif
