/* (C) 2005 Richard Mills / The Linux Academy Ltd.
 *
 * An event to record the result of a connect attempt.
 *
 * $Id: ConnectResultEvent.cc,v 1.2 2012/12/27 13:26:45 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include "ConnectResultEvent.hh"
#include "Debug.hh"
#include "Connection.hh"
#include "Tunneler.hh"

namespace HTTPTunnel {


// Construction/destruction
ConnectResultEvent::ConnectResultEvent(Tunneler* tunneler, unsigned int connID,
	const IPAddr& addr, Enums::Protocol prot, bool ssl, ConnectResultType type)
: Event(), m_tunneler(tunneler), m_connID(connID), m_addr(addr), m_protocol(prot),
  m_ssl(ssl), m_type(type)
{
}

ConnectResultEvent::~ConnectResultEvent()
{
}


// Display event details for debugging
void ConnectResultEvent::details(std::stringstream& dbg)
{
	dbg << "ConnectResultEvent: ";
	Event::details(dbg);
}


// Report the error
void ConnectResultEvent::execute(void)
{
	DPRINTV("ConnectResultEvent::execute()");

	// Let controlling tunneler know
	m_tunneler->connectResult(this);
}


/*************/
/* Accessors */
/*************/


// Get connection result is for
unsigned int ConnectResultEvent::getConnectionID(void) const
{
	return m_connID;
}

// Get address connect was to
IPAddr ConnectResultEvent::getAddr(void) const
{
	return m_addr;
}

// Get protocol connect used
Enums::Protocol ConnectResultEvent::getProtocol(void) const
{
	return m_protocol;
}

// Get whether SSL is used
bool ConnectResultEvent::getSSL(void) const
{
	return m_ssl;
}

// Get connect result type
ConnectResultEvent::ConnectResultType ConnectResultEvent::getType(void) const
{
	return m_type;
}

// Get connect result type as a string
std::string ConnectResultEvent::getTypeStr(ConnectResultType type)
{
	const char* typeStr[] = { "GENERAL_ERROR", "FIREWALLED", "ASYNC", "SUCCESS" };
	return typeStr[type];
}


}	// namespace

