/* (C) 2006 Richard Mills / The Linux Academy Ltd.
 *
 * Encapsulate settings for tunneling through a proxy.
 *
 * $Id: ProxySettings.cc,v 1.2 2012/12/27 13:27:22 rich Exp $
 *
 * This file is part of HTTPTunnel.
 *
 * HTTPTunnel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * HTTPTunnel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HTTPTunnel; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include <sstream>
#include "ProxySettings.hh"


namespace HTTPTunnel {


// Construction/destruction
ProxySettings::ProxySettings(std::string user, std::string domain, std::string passwd,
	IPAddr proxyIP)
: AuthSettings(user, domain, passwd), m_IP(proxyIP)
{
}

ProxySettings::ProxySettings(const ProxySettings& that)
: AuthSettings(that), m_IP(that.m_IP)
{
}

ProxySettings::~ProxySettings()
{
}


/*************/
/* Accessors */
/*************/


// Get proxy IP
IPAddr ProxySettings::getIP(void) const
{
	return m_IP;
}


/*************/
/* Utilities */
/*************/


// Construct tunneling proxy headers
std::string ProxySettings::getRequestHeader(std::string uri)
{
	std::stringstream res;

	// General proxy fields
	res << "Proxy-Connection: keep-alive\r\n";

	// Proxy authentication fields
	res << AuthSettings::getRequestHeader(uri);

	return res.str();
}


// Clear and reset any exisiting authentication scheme details
void ProxySettings::reset(void)
{
	if(m_authScheme != AUTH_HOLD) {
		// Can we short-circuit request header creation?
		if(m_authScheme == AUTH_BASIC) {
			// Hold current auth scheme
			m_authScheme = AUTH_HOLD;
		}
		else if(m_authScheme == AUTH_NTLM) {
			// It seems we don't need to keep sending the NTLM request header
			m_authScheme = AUTH_NONE;
			m_ntlmHandler.reset();
		}

		// Clear tried schemes
		m_triedSchemes.clear();
	}
}


/***********************/
/* Protected Interface */
/***********************/


// Get authorisation request header field identifier
std::string ProxySettings::getAuthRequestHeaderID(void) const
{
	return "Proxy-Authorization";
}


}	// namespace

